/*
package com.ys.bdtp.adm.mvvm.ui.examine

import android.annotation.SuppressLint
import android.os.Bundle
import android.webkit.*
import android.webkit.WebView.setWebContentsDebuggingEnabled
import android.widget.Toast
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.*
import androidx.compose.foundation.layout.*
import androidx.compose.foundation.shape.CircleShape
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material.Divider
import androidx.compose.material.Text
import androidx.compose.runtime.*
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import androidx.compose.ui.viewinterop.AndroidView
import com.google.gson.Gson
import com.ys.bdtp.adm.R
import com.ys.bdtp.adm.di.di
import com.ys.bdtp.adm.mvvm.model.vo.FunctionEndBlockModel
import com.ys.bdtp.adm.mvvm.model.vo.PageParam
import com.ys.bdtp.adm.mvvm.model.vo.SetFloorPathModel
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import org.kodein.di.DI
import org.kodein.di.DIAware
import org.kodein.di.android.closestDI
import org.kodein.di.compose.withDI

class ModelExamineActivity : ComponentActivity(), DIAware {
    override val di: DI by closestDI()
    val gson = Gson()

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            ModelExaminApp()
        }
    }


    @Preview
    @Composable
    fun ModelExaminApp() = withDI(di(LocalContext.current)) {
        Column {
            ModelExamineTitle()
            Divider(modifier = Modifier.height(1.dp).fillMaxWidth().background(Color(0XFFEFF0F1)))
            ModelExamineScreen()
        }
    }

    @Preview
    @Composable
    fun ModelExamineTitle() = withDI(di(LocalContext.current)) {
        Row(
            modifier = Modifier.fillMaxWidth()
                .background(Color.White).height(48.dp),
            verticalAlignment = Alignment.CenterVertically,
            horizontalArrangement = Arrangement.SpaceBetween
        ) {
            Row(modifier = Modifier.weight(1f)) { ModelExamineTitleLeft() }
            Row(modifier = Modifier.weight(1f)) { ModelExamineTitleMiddel() }
            Row(modifier = Modifier.weight(1f)) { ModelExamineTitleRight() }
        }
    }

    @Preview
    @Composable
    fun ModelExamineTitleLeft() = withDI(di(LocalContext.current)) {
        Row(
            modifier = Modifier
                .background(Color.White).height(48.dp).fillMaxWidth(),
            verticalAlignment = Alignment.CenterVertically,
            horizontalArrangement = Arrangement.Start
        ) {

            Spacer(modifier = Modifier.size(29.dp))

            Image(
                painter = painterResource(id = R.drawable.icon_back),
                modifier = Modifier.size(18.dp),
                contentDescription = null
            )

            Spacer(modifier = Modifier.size(22.dp))

            Divider(modifier = Modifier.width(1.dp).height(16.dp).background(Color(0XFFD8D8D8)))

            Spacer(modifier = Modifier.size(19.dp))

            Text(
                text = "测试项目",
                color = Color(0XFF1F2329),
                fontSize = 18.sp
            )

            Spacer(modifier = Modifier.size(14.dp))

            Image(
                painter = painterResource(id = R.drawable.icon_arrow_down),
                modifier = Modifier.size(12.dp),
                contentDescription = null
            )
        }
    }

    @Preview
    @Composable
    fun ModelExamineTitleMiddel() = withDI(di(LocalContext.current)) {
        Row(
            modifier = Modifier
                .background(Color.White).height(48.dp).fillMaxWidth(),
            verticalAlignment = Alignment.CenterVertically,
            horizontalArrangement = Arrangement.Center
        ) {
            Text(
                text = "选择对象",
                color = Color(0XFF0091FF),
                fontSize = 14.sp,
                modifier = Modifier.border(
                    border = BorderStroke(1.dp, color = Color(0XFF0091FF)),
                    shape = RoundedCornerShape(4.dp, 0.dp, 0.dp, 4.dp)
                ).padding(26.dp, 5.dp, 26.dp, 5.dp)
            )

            Text(
                text = "选择空间",
                color = Color(0XFF1F2429),
                fontSize = 14.sp,
                modifier = Modifier.border(
                    border = BorderStroke(1.dp, color = Color(0XFFC3C7CB)),
                    shape = RoundedCornerShape(0.dp, 4.dp, 4.dp, 0.dp)
                )
                    .padding(26.dp, 5.dp, 26.dp, 5.dp)
            )
        }
    }

    @Preview
    @Composable
    fun ModelExamineTitleRight() = withDI(di(LocalContext.current)) {
        Row(
            modifier = Modifier
                .background(Color.White).height(48.dp).fillMaxWidth(),
            verticalAlignment = Alignment.CenterVertically,
            horizontalArrangement = Arrangement.End
        ) {
            Box {
                Image(
                    painter = painterResource(id = R.drawable.icon_message),
                    modifier = Modifier.size(30.dp).padding(4.dp),
                    contentDescription = null
                )
                Text(
                    text = "2",
                    color = Color.White,
                    fontWeight = FontWeight.Bold,
                    textAlign = TextAlign.Center,
                    fontSize = 10.sp,
                    modifier = Modifier.background(Color(0XFFF54E45), shape = CircleShape).width(15.dp).height(15.dp)
                        .align(Alignment.TopEnd)
                )
            }

            Spacer(modifier = Modifier.size(24.dp))

            Text(
                text = "",
                modifier = Modifier.background(Color(0XFFD8D8D8)).width(1.dp).height(16.dp)
            )

            Spacer(modifier = Modifier.size(18.dp))

            Text(
                text = "业务角色",
                color = Color(0XFF1F2429),
                fontSize = 14.sp
            )

            Spacer(modifier = Modifier.size(13.dp))

            Image(
                painter = painterResource(id = R.drawable.icon_head),
                modifier = Modifier.size(24.dp),
                contentDescription = null
            )

            Spacer(modifier = Modifier.size(5.dp))

            Image(
                painter = painterResource(id = R.drawable.icon_arrow_down),
                modifier = Modifier.size(9.dp),
                contentDescription = null
            )

            Spacer(modifier = Modifier.size(30.dp))
        }
    }


}*/
