package com.ys.bdtp.adm.mvvm.ui.screen.project

import android.net.ConnectivityManager
import androidx.compose.foundation.ExperimentalFoundationApi
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.*
import androidx.compose.runtime.*
import androidx.compose.ui.Modifier
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import com.ys.bdtp.adm.app.isNet
import com.ys.bdtp.adm.app.theme.underColor
import com.ys.bdtp.adm.mvvm.model.FailureResponse
import com.ys.bdtp.adm.mvvm.model.SuccessResponse
import com.ys.bdtp.adm.mvvm.model.db.entity.ProjectEntity
import com.ys.bdtp.adm.mvvm.model.db.entity.UserEntity
import com.ys.bdtp.adm.mvvm.ui.compose.*
import com.ys.bdtp.adm.mvvm.ui.screen.main.LocalNavHostController
import com.ys.bdtp.adm.mvvm.ui.screen.main.Main
import com.ys.bdtp.adm.mvvm.vm.project.ProjectViewModel
import kotlinx.coroutines.launch
import org.kodein.di.compose.rememberInstance
import org.kodein.di.compose.rememberViewModel


@OptIn(ExperimentalFoundationApi::class)
@Composable
fun Project() {
    val vm by rememberViewModel<ProjectViewModel>()
    val cm by rememberInstance<ConnectivityManager>()
    val nav = LocalNavHostController.current!!
    val scope = rememberCoroutineScope()
    var user by remember { mutableStateOf<UserEntity?>(null) }
    var projects by remember { mutableStateOf<List<ProjectEntity>>(emptyList()) }

    var popupState by remember { mutableStateOf(false) }
    LaunchedEffect(Unit) {
        // isNet 联网，进行网络通信，获取账号信息也判断 token是否能用
        if (isNet(cm)) {
            when (val response = vm.getAccount()) {
                is SuccessResponse -> {
                    val account = response.data
                    vm.setCurrentAccount(account)
                    val up = vm.getUserWithProjectsById(account.id)
                    user = up.user
                    projects = up.projects
                }

                is FailureResponse -> {
                    val fail = response.fail
                    if (fail.code == "catch") {
                        // 提示网络问题
                    } else {
                        // 根据不同 code 进行不同操作
                    }
                }
            }
        } else {
            // 离线
            val u = vm.currentUser()
            if (u == null) {
                nav.navigate(Main.Login) {
                    popUpTo(Main.Project) {
                        inclusive = true
                    }
                }
            } else {
                val up = vm.getUserWithProjectsById(u.id)
                user = up.user
                projects = up.projects
            }
        }
    }

    Column(
        modifier = Modifier.fillMaxSize()
    ) {
        Head(
            left = {
                ProjectHeadLeft()
            },
            right = {
                HeadRight(
                    role = { "项目管家" },
                    click = {
                        popupState = !popupState
                    }
                )
            }
        )

        if (popupState) {
            LogoutPopup(
                click = {
                    scope.launch {
                        vm.logout()
                    }
                    popupState = false
                    nav.navigate(Main.Login) {
                        popUpTo(Main.Project) {
                            inclusive = true
                        }
                    }
                }
            )
        }

        Div(Div.Row)
        Column(
            modifier = Modifier
                .fillMaxSize()
                .wrapContentWidth()
                .background(underColor)
                .padding(horizontal = 32.dp, vertical = 40.dp)
        ) {
            if (projects.isEmpty())
                Blank()
            else
                ProjectContent(projects)

        }
    }
}

@Preview(
    widthDp = 1280,
    heightDp = 800,
    showBackground = true,
    backgroundColor = 0xFFFFFFFF
)
@Composable
fun PreviewProject() {
    Project()
}