package com.ys.bdtp.adm.mvvm.ui.screen.task

import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.layout.wrapContentWidth
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.getValue
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import com.ys.bdtp.adm.R
import com.ys.bdtp.adm.app.theme.underColor
import com.ys.bdtp.adm.mvvm.model.db.entity.ProjectEntity
import com.ys.bdtp.adm.mvvm.ui.compose.Head
import com.ys.bdtp.adm.mvvm.ui.compose.TaskType
import com.ys.bdtp.adm.mvvm.ui.compose.HeadRight
import com.ys.bdtp.adm.mvvm.ui.screen.main.LocalNavHostController
import com.ys.bdtp.adm.mvvm.vm.task.TaskViewModel
import org.kodein.di.compose.rememberViewModel

@Composable
fun Task(projectId: String) {
    val nav = LocalNavHostController.current!!
    val vm by rememberViewModel<TaskViewModel>()
    var project by remember { mutableStateOf<ProjectEntity?>(null) }

    LaunchedEffect(Unit) {
        project = vm.getProject(projectId)
    }

    Column(modifier = Modifier.fillMaxSize().background(Color.White)) {
        Head(
            left = {
                TaskHeadLeft(
                    title = "${project?.projectName}",
                    click = {
                        nav.navigateUp()
                    })
            },
            right = {
                HeadRight(
                    role = { "管家" },
                    click = { println("heiheihei") }
                )
            }
        )
        Spacer(
            modifier = Modifier.fillMaxWidth().height(1.dp).background(Color(0xFFEFF0F1))
        )

        Row {
            Box(
                modifier = Modifier
                    .fillMaxHeight()
                    .wrapContentWidth()
                    .background(color = underColor)
                    .padding(horizontal = 32.dp, vertical = 30.dp)
            ) {
                // 工作分类
                Column(
                    horizontalAlignment = Alignment.CenterHorizontally
                ) {
                    TaskType(R.drawable.project_task_cad, "CAD核查")
                    Spacer(modifier = Modifier.height(20.dp))
                    TaskType(R.drawable.project_task_space, "空间模型核查")
                    Spacer(modifier = Modifier.height(20.dp))
                    TaskType(R.drawable.project_task_electric, "机电核查")
                    Spacer(modifier = Modifier.height(20.dp))
                    TaskType(R.drawable.project_task_relation, "交付关系")
                    Spacer(modifier = Modifier.height(20.dp))
                    TaskType(R.drawable.project_task_offline, "离线数据")
                }
                // 项目切换

            }

            Spacer(modifier = Modifier.width(1.dp).fillMaxHeight().background(Color(0xFFE5E5E5)))

            Column(
                modifier = Modifier
                    .fillMaxHeight()
                    .wrapContentWidth()
                    .padding(horizontal = 40.dp, vertical = 32.dp)
            ) {
                //ProjectBlank()
                TaskContent("查看全部项目任务")
            }
        }
    }
}


@Preview(
    widthDp = 1137,
    heightDp = 711,
)
@Composable
fun PreviewProjectScreen() {
    Task("111")
}